@@ -104,9 +104,12 @@ class SpeechGraph:
                 logger.debug("%s", sentence_text)
                 # prinst("{}".format(sentence_text))
 
-                extraction = openie_client.extract(sentence_text)
-
-                ex_ollie[i] = extraction
+                try:
+                    extraction = openie_client.extract(sentence_text)
+                    ex_ollie[i] = extraction
+                except Exception as e:
+                    logger.warning(f'====== Skipping sentece {i+1}: Unknown Client Error =======')
+                    
             else:
                 logger.warning(
                     '====== Skipping sentence %s: Sentence has too few tokens: "%s" =======',
@@ -135,20 +138,20 @@ class SpeechGraph:
 
         if len(ollie_edges) == 0 and len(stanza_edges) != 0:
             edges = stanza_edges
-            logger.warning(
+            logger.info(
                 "++++ Ollie detected %s edges, but stanza detected %s. Therefore added edges detected by stanza.  ++++",
                 len(ollie_edges),
                 len(stanza_edges),
             )
         elif len(ollie_edges) == 0 and len(stanza_edges) == 0:
-            logger.warning(
+            logger.info(
                 "++++ Ollie detected %s edges and stanza also detected %s. No stanza edges were added. ++++",
                 len(ollie_edges),
                 len(stanza_edges),
             )
 
         else:
-            logger.warning(
+            logger.info(
                 "++++ Ollie detected %s edges, so no stanza edges were added.  ++++",
                 len(ollie_edges),
             )
